<?php
namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\Controller;
use Modules\Cadastros\Services\Gql33000QualificacaoService;

class Gql33000QualificacaoController
{
    protected $connection;
    
    public function __construct (Gql33000QualificacaoService $service, $connection)
    {
        $this->service       = $service;
        $this->connection    = $connection;
    }
    
    public function verificaDescricao($row) {
        $descqualif = $this->service->getDescQualificacao($row);
        
        if ($descqualif) {
            throw new \Exception("Descrição de Qualificação já cadastrada.");	
        }
    }
    
    public function insertQualificacao(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getRow(); 
            
            $codqualif = $this->service->getCodQualificacao($row);
            
            if ($codqualif) {
            	throw new \Exception("Código de Qualificação já cadastrado.");	
            }
            
            self::verificaDescricao($row);
            
			$this->service->insertQualificacao($row);
			
			$response->addMessage(new Message("Salvo com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
    public function updateQualificacao(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            self::verificaDescricao($row);
            
            $this->service->updateQualificacao($row);
            
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function deleteQualificacao(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getRow();
            
			$this->service->deleteQualificacao($row);
			
			$response->addMessage(new Message("Alterado com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
}