<?php
namespace Modules\Qualificacao\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Report\ReportService;
use Modules\Qualificacao\Services\Gql00900TesteDoProdutoService;
use Zeedhi\Framework\DataSource\DataSet;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\GER\Utilities\DataSourceUtil;
use Exception;

class Gql00900TesteDoProduto
{
    
    protected $connection;
    protected $entityManager;
    protected $environment;
    protected $crudService;
    protected $novoCodigo;
    
    public function __construct(Gql00900TesteDoProdutoService $service, $connection, $entityManager, $environment, $crudService, $novoCodigo) {
        $this->connection        = $connection;
        $this->service           = $service;
        $this->entityManager     = $entityManager;
        $this->environment       = $environment;
        $this->crudService       = $crudService;
        $this->novoCodigo        = $novoCodigo;
    }
    
    public function retornaMarca(DTO\Request\Row $request, DTO\Response $response){
        try {
            $data = $request->getRow();
            if(!empty($data) && !empty($data[0]["CDMARCA"])){
                $marca = $data[0]["CDMARCA"];
            } else {
                $sql = "SELECT CDMARCA FROM MARCA";
                $marca = $this->entityManager->getConnection()->fetchAll($sql);
                $marca = implode('_', array_column($marca, 'CDMARCA'));
            }
            } catch (\Exception $e) {
            throw $e;
        }
        $nrlistaMarca = $this->criarListaValores($marca);
        $response->addDataSet(new DataSet('data', array("NRLISTAMARCA" => $nrlistaMarca)));
     }
     
    public function criarListaValores($valores){
        $this->entityManager->beginTransaction();
        $lista = explode('_',$valores);
        $nrlista = $this->novoCodigo->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
        try{
            foreach($lista as $key){
                $this->insertLista($nrlista, $key);
            }
            $this->entityManager->commit();
            return $nrlista;
        } catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function insertLista($nrlista, $key) {
        $nrorg = $this->environment->getNrorg();
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $key,
            "NRORG"   => $nrorg
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) VALUES (:NRLISTA, :CDLISTA, :NRORG)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $nrlista;
    }
    
    public function retornaNumero(DTO\Request\Row $request, DTO\Response $response){
        try {
            $data = $request->getRow();
            if(!empty($data) && !empty($data[0]["NNRTESTEPROD"])){
                $numero = $data[0]["NNRTESTEPROD"];
            } else {
                $sql = "SELECT NRTESTEPROD FROM TESTEPROD";
                $numero = $this->entityManager->getConnection()->fetchAll($sql);
                $numero = implode('_', array_column($numero, 'NRTESTEPROD'));
            }
        } catch (\Exception $e) {
            throw $e;
        }
        $nrlistaNumero = $this->criarListaValoresNumero($numero);
        $response->addDataSet(new DataSet('data', array("NRLISTANUMERO" => $nrlistaNumero)));
     }
     
    public function criarListaValoresNumero($valores){
        $this->entityManager->beginTransaction();
        $lista = explode('_',$valores);
        $nrlista = $this->novoCodigo->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
        try{
            foreach($lista as $key){
                $this->insertListaNumero($nrlista, $key);
            }
            $this->entityManager->commit();
            return $nrlista;
        } catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function insertListaNumero($nrlista, $key) {
        $nrorg = $this->environment->getNrorg();
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $key,
            "NRORG"   => $nrorg
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) VALUES (:NRLISTA, :CDLISTA, :NRORG)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $nrlista;
    }
    
    public function salvaTeste(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getRow(); 
            $nrCodigo = $this->novoCodigo->getCodeByTableName('TESTEPROD', $this->environment->getNrorgTrab(), 1, 10, false);
            $row["NRTESTEPROD"] = $nrCodigo;
			$this->service->salvaTeste($row);
			$response->addMessage(new Message("Salvo com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function atualizaTeste(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getRow(); 
			$this->service->atualizaTeste($row);
			$response->addMessage(new Message("Alterado com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function apagaTeste(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getRow(); 
			$this->service->apagaTeste($row);
			$response->addMessage(new Message("Deletado com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function salvaObservacao(DTO\Request $request, DTO\Response $response) {
	    try {
    	    $row = $request->getRow();
            $query = "SELECT * FROM OBSTESTPROD WHERE NRTESTEPROD = {$row['NRTESTEPROD']}";
            $std = $this->connection->prepare($query);
            $std->execute();
            $observacao = $std->fetch();
            $tam = strlen($row['DSOBSTEST']);
            if($tam >2000){
                throw new Exception('LIMITECARACTERES');
            }
            if($observacao) {
                if(strip_tags($row['DSOBSTEST']) == ""){
                    $this->service->apagaObservacao($row);
                }else{
                    $this->service->atualizaObservacao($row);
                }
            } else {
                if(strip_tags($row['DSOBSTEST']) == "") {
                    $this->service->apagaObservacao($row);
                } else{
                    $this->service->salvaObservacao($row);
                }
            }
            $response->addMessage(new Message("Alterado com sucesso."));
	    } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function addTipoPrato(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getRow(); 
			$this->service->addTipoPrato($row);
			$response->addMessage(new Message("Salvo com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function deleteTipoPrato(DTO\Request $request, DTO\Response $response) {
		try {
            $rows = $request->getRow(); 
			$this->service->deleteTipoPrato($rows);
			$response->addMessage(new Message("Deletado com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function addMarcaReferencia(DTO\Request $request, DTO\Response $response) {
		try {
            $row = $request->getRow(); 
			$this->service->addMarcaReferencia($row);
			$response->addMessage(new Message("Salvo com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function deleteMarcaRefefencia(DTO\Request $request, DTO\Response $response) {
		try {
            $rows = $request->getRow(); 
			$this->service->deleteMarcaRefefencia($rows);
			$response->addMessage(new Message("Deletado com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function salvaCustoBeneficio(DTO\Request $request, DTO\Response $response) {
	    try {
    	    $row = $request->getRow();
            $query = "SELECT * FROM CUSBENTEST WHERE NRTESTEPROD = {$row['NRTESTEPROD']}";
            $std = $this->connection->prepare($query);
            $std->execute();
            $observacao = $std->fetch();
            $tam = strlen($row['DSCUSBENTEST']);
            if($tam >2000){
                throw new Exception('LIMITECARACTERES');
            }
            if($observacao) {
                if(strip_tags($row['DSCUSBENTEST']) == ""){
                    $this->service->apagaCustoBeneficio($row);
                }else{
                    $this->service->atualizaCustoBeneficio($row);
                }
            } else {
                if(strip_tags($row['DSCUSBENTEST']) == "") {
                    $this->service->apagaCustoBeneficio($row);
                } else{
                    $this->service->salvaCustoBeneficio($row);
                }
            }
            $response->addMessage(new Message("Alterado com sucesso."));
	    } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function alteraRendimento(DTO\Request $request, DTO\Response $response){
	    try {
    	    $row = $request->getRow();
    	    $this->connection->beginTransaction();
    	    $this->service->procedureUpdateRendimento($row);
    	    $this->connection->commit();
	    } catch (\Exception $e) {
	        $this->connection->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function salvaCadastramentoAutomatico(DTO\Request $request, DTO\Response $response){
	    try {
    	    $row = $request->getRow();
    	    $this->service->salvaCadastramentoAutomatico($row);
	    } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
}