<?php
namespace Modules\Relatorios\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Report\ReportService;

class Gql01000ValidadeQualificacaoFornecedoresController extends \Zeedhi\Framework\Controller\Report
{
    protected $qr2Strategy;
    protected $stNomeRel;
    protected $stExtensao;
    protected $environment;
    protected $connection;
    protected $birtStrategy;
    protected $newCode;
    
    public function __construct(reportService $reportService, $qr2Strategy, $environment, $connection, $birtStrategy, $newCode) 
    {
        parent::__construct($reportService);
        $this->qr2Strategy  = $qr2Strategy;
        $this->environment  = $environment;
        $this->connection   = $connection;
        $this->birtStrategy = $birtStrategy;
        $this->newCode      = $newCode;
    }
    
    protected $reportMapping = array ();
        
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $row['NRORG'] = $this->environment->getNrOrg();
        
        if($row['FORNECEDOR'] != 'T'){
            $nrlistaForn= $this->criarListaValores($row['FORNECEDOR']);
            $row['FORNECEDOR'] = "_NRLISTA=".$nrlistaForn;
        }
        
        $this->birtStrategy->setReportFormat($row['QR2TYPE']);
        $this->stNomeRel = $this->getReportName($row);
        $row['FORNECEDOR1'] = $row['FORNECEDOR'];
        $row['QUALIFICACAO1'] = $row['QUALIFICACAO'];
        $this->reportMapping[$this->stNomeRel] =
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'FORNECEDOR'        => 'L_CDFORNECED',
                'FORNECEDOR1'       => 'P_CDFORNTODOS',
                'SITUACAO'          => 'P_IDSITUA',
                'QUALIFICACAO'      => 'P_CDQUALIF',
                'QUALIFICACAO1'     => 'P_CDQUALTODAS',
                'DATAINI'           => 'P_DTINICIAL',
                'DATAFIN'           => 'P_DTFINAL',
                'VALIDADE'          => 'P_IDTIPOVAL',
                'IDTIPO'            => 'P_IDTIPO',
                'NRORG'             => 'P_NRORG'
            ),
        );
    }
    
    protected function criarListaValores($lista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    
    public function getReportData(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrog = $this->getNrorg();
        if($nrog != null) {
            $this->environment->setNrOrgTrab($nrog);
        }
        $reportDecoratorController = new ReportDecorator($this->environment);
        $reportData = $reportDecoratorController->getData($request, $response);
    }

    public function getNrorg() {
        $nrorg = null;
        $fileDir = \Teknisa\Libs\Util\Utilities::getProductBasePath() . '/modules/login/backend/config/oAccCustom.tek';
        if (file_exists($fileDir)) {
            $fileContents  = file_get_contents($fileDir);
            $fileDecrypted = \Teknisa\Libs\Util\Utilities::zeedhiDecrypt($fileContents, \Teknisa\Libs\Util\Utilities::LOGIN_CRYPT_STRING);
            $fileDecoded   = @json_decode($fileDecrypted, true);
            if(isset($fileDecoded['organizationId']) && is_numeric($fileDecoded['organizationId'])) {
                $nrorg = $fileDecoded['organizationId'];
            }
        }
        return $nrorg;
    }
}